@@ -580,11 +580,11 @@ class Graph(BaseGraph):
         :rtype: list(Graph)
         """
         if isinstance(self.blocks, BlockArray):
-            logging.info("Using fast way to get first block")
+            logging.debug("Using fast way to get first block")
             min_block_id = self.min_node
             assert min_block_id in self.blocks
             if len(self.reverse_adj_list[min_block_id]) == 0:
-                logging.info("Fast way used")
+                logging.debug("Fast way used")
                 return [min_block_id]
 
         return [b for b in self._possible_node_ids()
@@ -672,7 +672,7 @@ class Graph(BaseGraph):
 
     @classmethod
     def from_file(cls, file_name):
-        logging.info("Reading Offset Based Graph from file: %s" % file_name)
+        logging.debug("Reading Offset Based Graph from file: %s" % file_name)
         file = open(file_name, "rb")
         data = np.load(file)
 
@@ -698,7 +698,6 @@ class Graph(BaseGraph):
                     adj_list=adj_list,
                     rev_adj_list=rev_adj_list)
         file.close()
-        logging.info("Done reading from file")
         return graph
 
     def to_numpy_file(self, name):
